<?php

// $Id: rss10.inc,v 1.3 2001/05/20 17:58:02 edmundd Exp $
//
// A convenience class to make it easy to write RSS classes
// Edd Dumbill <mailto:edd+rsswriter@usefulinc.com>
//
// $Log: rss10.inc,v $
// Revision 1.3  2001/05/20 17:58:02  edmundd
// Final distribution tweaks.
//
// Revision 1.2  2001/05/20 17:41:30  edmundd
// Ready for distribution.
//
// Revision 1.1  2001/05/20 17:01:43  edmundd
// First functional draft of code working.
//
// Revision 1.1  2001/05/17 18:17:46  edmundd
// Start of a convenience library to help RSS1.0 creation
//

// Modified by Bob den Otter, so as to make it output to disk.
// check www.usefulinc.com for the original.

class RSSWriter {

function RSSWriter($uri, $title, $description, $meta=array()) {
	global $global_pref, $HTTP_SERVER_VARS;

	$this->chaninfo=array();
	$this->website=$uri;
	$this->chaninfo["link"]=$uri;
	$this->chaninfo["description"]=$description;
	$this->chaninfo["title"]=$title;
	$this->items=array();
	$this->modules=array("dc" => "http://purl.org/dc/elements/1.1/");
	$this->channelURI="http://".$HTTP_SERVER_VARS['HTTP_HOST'].$global_pref['log_url'].$global_pref['rss'];
//	$this->channelURI="http://" . $GLOBALS["SERVER_NAME"] . $GLOBALS["REQUEST_URI"];
	foreach ($meta as $key => $value) {
		$this->chaninfo[$key]=$value;
	}
}

function useModule($prefix, $uri) {
	$this->modules[$prefix]=$uri;
}

function setImage($imgURI, $imgAlt, $imgWidth=88, $imgHeight=31) {
	$this->image=array(
		"uri" => $imgURI, "title" => $imgAlt, "width" => $imgWidth,
		"height" => $imgHeight);
}

function addItem($uri, $title, $meta=array()) {
	$item=array("uri" => $uri, "link" => $uri, 
		"title" => $this->deTag($title));
	foreach ($meta as $key => $value) {
		if ($key == "description" || $key == "dc:description") {
			$value=$this->deTag($value);
		}
		$item[$key]=$value;
	}
	$this->items[]=$item;
}

function serialize($file="") {
	global $rss_fp, $global_pref;

	$rss_fp=fopen("../".$global_pref['rss'],"w");
	$this->preamble();
	$this->channelinfo();
//	$this->image();
	$this->items();
	$this->postamble();
	fclose($rss_fp);
}

function deTag($in) {
  while(ereg('<[^>]+>', $in)) {
	$in=ereg_replace('<[^>]+>', '', $in);
  }
  return $in;
}

function preamble() {
	global $rss_fp;

	//header("Content-type: text/xml");
	fwrite($rss_fp, '<?xml version="1.0" encoding="iso-8859-1"?>
<rdf:RDF 
         xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
         xmlns="http://purl.org/rss/1.0/"
         xmlns:mn="http://usefulinc.com/rss/manifest/"
');
	foreach ($this->modules as $prefix => $uri) {
		fwrite($rss_fp, "         xmlns:${prefix}=\"${uri}\"\n");
	}
	fwrite($rss_fp, ">\n\n");
}

function channelinfo() {
		global $rss_fp;
	fwrite($rss_fp,  '  <channel rdf:about="' .  $this->channelURI . '">
');
	$i=$this->chaninfo;
	foreach (array("title", "link", "dc:source", "description", "dc:language", "dc:publisher",
		"dc:creator", "dc:rights") as $f) {
		if (isset($i[$f])) {
			fwrite($rss_fp, "    <${f}>" . htmlspecialchars($i[$f]) . "</${f}>\n");
		}
	}
	if (isset($this->image)) {
		fwrite($rss_fp, "    <image rdf:resource=\"" . htmlspecialchars($this->image["uri"]) . "\" />\n");
	}
	fwrite($rss_fp, "    <items>\n");
	fwrite($rss_fp, "      <rdf:Seq>\n");
	foreach ($this->items as $i) {
		fwrite($rss_fp, "        <rdf:li rdf:resource=\"" . htmlspecialchars($i["uri"]) . "\" />\n");
	}
	fwrite($rss_fp, "      </rdf:Seq>\n");
	fwrite($rss_fp, "    </items>\n");
	fwrite($rss_fp, "  </channel>\n\n");
}

function image() {
		global $rss_fp;
	if (isset($this->image)) {
	fwrite($rss_fp, "  <image rdf:about=\"" . htmlspecialchars($this->image["uri"]) . "\">\n");
    fwrite($rss_fp, "     <title>" . htmlspecialchars($this->image["title"]) . "</title>\n");
    fwrite($rss_fp, "     <url>" . htmlspecialchars($this->image["uri"]) . "</url>\n");
    fwrite($rss_fp, "     <link>" . htmlspecialchars($this->website) . "</link>\n");
    if ($this->chaninfo["description"]) 
   	 fwrite($rss_fp, "     <dc:description>" . htmlspecialchars($this->chaninfo["description"]) . 
   	 	"</dc:description>\n");
	fwrite($rss_fp, "  </image>\n\n");
	}
}

function postamble() {
	global $rss_fp;
	fwrite($rss_fp,  '  <rdf:Description rdf:ID="manifest">
    <mn:channels>
      <rdf:Seq>
        <rdf:li rdf:resource="' . $this->channelURI . '" />
      </rdf:Seq>
    </mn:channels>
  </rdf:Description>

</rdf:RDF>
');
}

function items() {
		global $rss_fp;
	foreach ($this->items as $item) {
		fwrite($rss_fp, "  <item rdf:about=\"" .  htmlspecialchars($item["uri"]) . "\">\n");
		foreach ($item as $key => $value) {
			if ($key!="uri") {
				if (is_array($value)) {
					foreach ($value as $v1) {
						fwrite($rss_fp, "    <${key}>" . htmlspecialchars($v1) . "</${key}>\n");
					}
				} else {
					fwrite($rss_fp, "    <${key}>" . htmlspecialchars($value) . "</${key}>\n");
				}
			}
		}
		fwrite($rss_fp, "  </item>\n\n");
	}
}

}

?>
